

require "import"
import "android.content.Context"
import "android.content.Intent"

local IntentFilter = luajava.bindClass("android.content.IntentFilter")
local BatteryManager = luajava.bindClass("android.os.BatteryManager")

function getBatteryStatus()
    local batteryStatus = {}
    
    local batteryManager = service.getSystemService(Context.BATTERY_SERVICE)
    
    -- Get current battery level
    batteryStatus["batteryLevel"] = batteryManager.getIntProperty(4) -- BatteryManager.BATTERY_PROPERTY_CAPACITY = 4

    -- Get battery voltage
    local batteryStatusIntent = service.registerReceiver(nil, IntentFilter(Intent.ACTION_BATTERY_CHANGED))
    local voltage = batteryStatusIntent.getIntExtra(BatteryManager.EXTRA_VOLTAGE, 0)
    batteryStatus["batteryVoltage"] = voltage / 1000.0 -- converting mV to V

    -- Get charging status and voltage if charging
    local status = batteryStatusIntent.getIntExtra(BatteryManager.EXTRA_STATUS, -1)
    if status == 2 or status == 5 then -- BatteryManager.BATTERY_STATUS_CHARGING = 2, BatteryManager.BATTERY_STATUS_FULL = 5
        batteryStatus["isCharging"] = true
        local chargingVoltage = batteryStatusIntent.getIntExtra(BatteryManager.EXTRA_VOLTAGE, 0)
        batteryStatus["chargingVoltage"] = chargingVoltage / 1000.0 -- converting mV to V
    else
        batteryStatus["isCharging"] = false
    end

    -- Get temperature
    local temperature = batteryStatusIntent.getIntExtra(BatteryManager.EXTRA_TEMPERATURE, 0)
    batteryStatus["batteryTemperature"] = temperature / 10.0 -- converting tenths of a degree Celsius to Celsius

    return batteryStatus
end

function printBatteryStatus(status)
    print("Battery Level: " .. status["batteryLevel"] .. "%")
    print("Battery Voltage: " .. status["batteryVoltage"] .. " V")
    print("Battery Temperature: " .. status["batteryTemperature"] .. " °C")

    if status["isCharging"] then
        print("Charging Status: Charging")
        print("Charging Voltage: " .. status["chargingVoltage"] .. " V")
    else
        print("Charging Status: Not Charging")
    end
end

function updateBatteryStatus()
    local status = getBatteryStatus()
    printBatteryStatus(status)
end

-- Initial battery status
local status = getBatteryStatus()
printBatteryStatus(status)

-- Implement automatic updates using a Lua table as a timer task
local timer = {
    run = function ()
        updateBatteryStatus()
        local handler = Handler()
        handler.postDelayed(timer, 5000) -- 5000 milliseconds = 5 seconds
    end
}

-- Schedule the task to run every 5 seconds
local Handler = luajava.bindClass("android.os.Handler")
local handler = Handler()
handler.postDelayed(timer, 5000) -- 5000 milliseconds = 5 seconds